@@ -12,19 +12,30 @@ from pyzentao.attribute_dict import AttributeDict
 from pyzentao.api import API
 from pyzentao.session import Session
 from pyzentao.response import Response
-from pyzentao.common import get_json
-
-
-def make_api_method(api, **kwargs):
-    def _api(self, **kwargs):
-        return self.request(api, **kwargs)
-    return _api
+from pyzentao.utils import get_json
 
 
 class Zentao:
     """zentao main entry class"""
 
     def __init__(self, config):
+        """initializer
+
+        config can be a config file path or a dict, config file should be yaml
+        which contains:
+            zentao:
+                url: http://my.zentao.site/zentao
+                username: admin
+                password: 123456
+                spec: /path/to/spec
+
+        or dict which contains:
+            - url: http://my.zentao.site/zentao
+            - username: admin
+            - password: 123456
+            - spec: /path/to/spec
+        """
+
         super(Zentao, self).__init__()
 
         # load config
@@ -45,7 +56,8 @@ class Zentao:
     def request(self, api_name, **kwargs):
         """wrapper for requests.request"""
 
-        self.session.connect()
+        # connect session
+        self.session.connect(kwargs.pop("force_reconnect", False))
 
         # check out params
         params = kwargs.pop("params", {})
@@ -57,6 +69,7 @@ class Zentao:
         # get api spec
         api = self.apis.get(api_name, kwargs)
 
+        # send request
         response = get_json(requests.request(
             method=api.get("method", "GET"),
             url=api.get("url"),
@@ -70,6 +83,11 @@ class Zentao:
         else:
             return Response(response)
 
+    def reconnect(self):
+        """force zentao session reconnect"""
+
+        return self.session.connect(force_reconnect=True)
+
 # protected
     def _init_apis(self):
         """initialize apis"""
@@ -77,13 +95,12 @@ class Zentao:
         # load api specs
         self.apis = API(
             base_url=self.config.url,
-            version=self.config.version,
-            config=self.config.get("spec", None)
+            spec=self.config.spec
         )
 
         # generate methods by api name
         for api in self.apis.names():
-            setattr(Zentao, api, make_api_method(api))
+            setattr(Zentao, api, self._make_api_method(api))
 
     def _load_config(self, config):
         """load configuration"""
@@ -98,9 +115,9 @@ class Zentao:
 
         self.config = AttributeDict({
             "url": "",
-            "version": "15",
             "username": "",
             "password": "",
+            "spec": None,
         })
         self.config.update(cfg)
 
@@ -108,4 +125,11 @@ class Zentao:
         if not self.config.url.endswith("/"):
             self.config.url += "/"
 
+    @staticmethod
+    def _make_api_method(api, **kwargs):
+        def _api(self, **kwargs):
+            return self.request(api, **kwargs)
+        return _api
+
+
 # end
